==> estateplat-common-1.2.3-20180412.113022-62-sources.jar: cn/gtmap/estateplat/model/server/core/BdcYy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 异议登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_yy")
public class BdcYy extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String yysx;//异议事项
    private String zxyyh;//注销异议业务号
    private String zxyyyy;//注销异议原因
    private Date zxsj;//注销登记时间
    private String zxdbr;//注销登簿人
    private String qllx;//权利类型
    /*private String proid;//项目ID*/
    private Integer qszt;//权属状态
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String ywh;//业务号
    private String qt;//其他
    private String issx;//是否失效

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_yy表增加冗余字段ywr、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、bdcqzmh、bdcdybh、zl
     */
    private String ywr; //异议人

    private String ywrzjzl; //异议人证件种类

    private String ywrzjh; //异议人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getZxyyh() {
        return zxyyh;
    }

    public void setZxyyh(String zxyyh) {
        this.zxyyh = zxyyh;
    }

    public String getZxyyyy() {
        return zxyyyy;
    }

    public void setZxyyyy(String zxyyyy) {
        this.zxyyyy = zxyyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getIssx() {
        return issx;
    }

    public void setIssx(String issx) {
        this.issx = issx;
    }
}

==> estateplat-common-1.2.3-20180506.025257-76-sources.jar: cn/gtmap/estateplat/model/server/core/BdcYy.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 异议登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_yy")
public class BdcYy extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String yysx;//异议事项
    private String zxyyh;//注销异议业务号
    private String zxyyyy;//注销异议原因
    private Date zxsj;//注销登记时间
    private String zxdbr;//注销登簿人
    private String qllx;//权利类型
    /*private String proid;//项目ID*/
    private Integer qszt;//权属状态
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private String ywh;//业务号
    private String qt;//其他
    private String issx;//是否失效

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_yy表增加冗余字段ywr、ywrzjzl、ywrzjh、bdcdyh、bdcqzh、bdcqzmh、bdcdybh、zl
     */
    private String ywr; //异议人

    private String ywrzjzl; //异议人证件种类

    private String ywrzjh; //异议人证件号

    private String bdcdyh; //不动产单元号

    private String bdcqzh; //不动产权证号

    private String bdcqzmh; //不动产权证明号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落
    private String qlqtzk; //权利其他状况

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getBdcqzmh() {
        return bdcqzmh;
    }

    public void setBdcqzmh(String bdcqzmh) {
        this.bdcqzmh = bdcqzmh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getYysx() {
        return yysx;
    }

    public void setYysx(String yysx) {
        this.yysx = yysx;
    }

    public String getZxyyh() {
        return zxyyh;
    }

    public void setZxyyh(String zxyyh) {
        this.zxyyh = zxyyh;
    }

    public String getZxyyyy() {
        return zxyyyy;
    }

    public void setZxyyyy(String zxyyyy) {
        this.zxyyyy = zxyyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public String getIssx() {
        return issx;
    }

    public void setIssx(String issx) {
        this.issx = issx;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
